package com.happy.service;

import com.happy.Model.Admin;
import com.happy.Model.AdminManager;
import com.happy.Model.weixin.CodeEntity;

import java.util.List;

public interface AppService {

    public CodeEntity getCodeInfo(String code);

    // 登录
    public Admin login(String admin_name, String password);

    public Admin queryByOpenid(String openid);

    public Admin queryByNameAndOpenid(String admin_name,String openid);

    public int updateOpenid(String openid,String admin_name);

    public int updateOpenidNull(String openid);

    /**********************
     * ********商户绑定**********
     * ********************/
    public AdminManager login_ma(String admin_name, String password);

    public AdminManager queryMaByOpenid(String openid);

    public AdminManager queryMaByNameAndOpenid(String admin_name,String openid);

    public int updateMaOpenid(String openid,String admin_name);

    public int updateMaOpenidNull(String openid);

}
